@@ -4,7 +4,7 @@
     
     Copyright (C) 1999 David A. Hinds -- dahinds@users.sourceforge.net
 
-    3c589_cs.c 1.161 2001/08/24 11:39:37
+    3c589_cs.c 1.163 2001/12/07 02:26:21
 
     The network driver code is based on Donald Becker's 3c589 code:
     
@@ -115,33 +115,35 @@ struct el3_private {
 
 static char *if_names[] = { "auto", "10baseT", "10base2", "AUI" };
 
+/*====================================================================*/
+
+/* Module parameters */
+
+MODULE_AUTHOR("David Hinds <dahinds@users.sourceforge.net>");
+MODULE_DESCRIPTION("3Com 3c589 series PCMCIA ethernet driver");
+MODULE_LICENSE("GPL");
+
+#define INT_MODULE_PARM(n, v) static int n = v; MODULE_PARM(n, "i")
+
+/* Special hook for setting if_port when module is loaded */
+INT_MODULE_PARM(if_port, 0);
+
+/* Bit map of interrupts to choose from */
+INT_MODULE_PARM(irq_mask, 0xdeb8);
+static int irq_list[4] = { -1 };
+MODULE_PARM(irq_list, "1-4i");
+
 #ifdef PCMCIA_DEBUG
-static int pc_debug = PCMCIA_DEBUG;
-MODULE_PARM(pc_debug, "i");
+INT_MODULE_PARM(pc_debug, PCMCIA_DEBUG);
 #define DEBUG(n, args...) if (pc_debug>(n)) printk(KERN_DEBUG args)
 static char *version =
-"3c589_cs.c 1.161 2001/08/24 11:39:37 (David Hinds)";
+"3c589_cs.c 1.163 2001/12/07 02:26:21 (David Hinds)";
 #else
 #define DEBUG(n, args...)
 #endif
 
 /*====================================================================*/
 
-/* Parameters that can be set with 'insmod' */
-
-/* Special hook for setting if_port when module is loaded */
-static int if_port = 0;
-
-/* Bit map of interrupts to choose from */
-static u_int irq_mask = 0xdeb8;
-static int irq_list[4] = { -1 };
-
-MODULE_PARM(if_port, "i");
-MODULE_PARM(irq_mask, "i");
-MODULE_PARM(irq_list, "1-4i");
-
-/*====================================================================*/
-
 static void tc589_config(dev_link_t *link);
 static void tc589_release(u_long arg);
 static int tc589_event(event_t event, int priority,
@@ -736,7 +738,7 @@ static int el3_start_xmit(struct sk_buff *skb, struct net_device *dev)
     outw(skb->len, ioaddr + TX_FIFO);
     outw(0x00, ioaddr + TX_FIFO);
     /* ... and the packet rounded to a doubleword. */
-    outsl_ns(ioaddr + TX_FIFO, skb->data, (skb->len + 3) >> 2);
+    outsw_ns(ioaddr + TX_FIFO, skb->data, (skb->len + 3) >> 1);
 
     dev->trans_start = jiffies;
     if (inw(ioaddr + TX_FREE) > 1536) {
@@ -995,8 +997,8 @@ static int el3_rx(struct net_device *dev)
 	    if (skb != NULL) {
 		skb->dev = dev;
 		skb_reserve(skb, 2);
-		insl_ns(ioaddr+RX_FIFO, skb_put(skb, pkt_len),
-			(pkt_len+3)>>2);
+		insw_ns(ioaddr+RX_FIFO, skb_put(skb, pkt_len),
+			(pkt_len+3)>>1);
 		skb->protocol = eth_type_trans(skb, dev);
 		netif_rx(skb);
 		dev->last_rx = jiffies;
